summaryrefslogtreecommitdiff
path: root/src/lib/job.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-02-12 21:48:06 +0000
committerCarl Hetherington <cth@carlh.net>2013-02-12 21:48:06 +0000
commit9b78074e1487ac263f84fd1132735fba83045719 (patch)
tree286f931e307356ec7d4d9d226aa0d862bcd02987 /src/lib/job.h
parentb77dd4f1ef4d6a1c0c36499f82835e0457469dbd (diff)
Add details button to job manager; stretch jobs across the whole of the bottom of the frame; give a better error on low disc space conditions (#48).
Diffstat (limited to 'src/lib/job.h')
-rw-r--r--src/lib/job.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/lib/job.h b/src/lib/job.h
index f32cfa811..1ea0a9b17 100644
--- a/src/lib/job.h
+++ b/src/lib/job.h
@@ -53,7 +53,8 @@ public:
bool finished_ok () const;
bool finished_in_error () const;
- std::string error () const;
+ std::string error_summary () const;
+ std::string error_details () const;
int elapsed_time () const;
virtual std::string status () const;
@@ -83,7 +84,7 @@ protected:
};
void set_state (State);
- void set_error (std::string e);
+ void set_error (std::string s, std::string d);
/** Film for this job */
boost::shared_ptr<Film> _film;
@@ -98,8 +99,9 @@ private:
mutable boost::mutex _state_mutex;
/** current state of the job */
State _state;
- /** message for an error that has occurred (when state == FINISHED_ERROR) */
- std::string _error;
+ /** summary of an error that has occurred (when state == FINISHED_ERROR) */
+ std::string _error_summary;
+ std::string _error_details;
/** time that this job was started */
time_t _start_time;